summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/petaltree2uml.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-09 02:23:29 +0000
commit9150603ad32928e9c514c0492a8518b742d82ac3 (patch)
tree6e3f83e2b94146bb42eed57eb6dd8f2fb0369e6f /umbrello/umbrello/petaltree2uml.cpp
parent6b126a99d5eecef5cb96589ed5c2e522bcb06ca9 (diff)
downloadtdesdk-9150603ad32928e9c514c0492a8518b742d82ac3.tar.gz
tdesdk-9150603ad32928e9c514c0492a8518b742d82ac3.zip
Remove the tq in front of these incorrectly TQt4-converted methods/data members:
tqrepaint[...] tqinvalidate[...] tqparent[...] tqmask[...] tqlayout[...] tqalignment[...] git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1240522 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'umbrello/umbrello/petaltree2uml.cpp')
-rw-r--r--umbrello/umbrello/petaltree2uml.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/umbrello/umbrello/petaltree2uml.cpp b/umbrello/umbrello/petaltree2uml.cpp
index dc650a5d..42fa038d 100644
--- a/umbrello/umbrello/petaltree2uml.cpp
+++ b/umbrello/umbrello/petaltree2uml.cpp
@@ -310,10 +310,10 @@ protected:
* @param node Pointer to the PetalNode which may contain a controlled unit
* @param name Name of the current node
* @param id TQUID of the current node
* @param tqparentPkg Pointer to the current tqparent UMLPackage.
* @return True if the node actually contained a controlled unit.
*/
-bool handleControlledUnit(PetalNode *node, const TQString& name, Uml::IDType id, UMLPackage *tqparentPkg) {
+bool handleControlledUnit(PetalNode *node, const TQString& name, Uml::IDType id, UMLPackage *parentPkg) {
if (node->findAttribute("is_unit").string != "TRUE")
return false;
bool is_loaded = (node->findAttribute("is_loaded").string != "FALSE");
@@ -335,7 +335,7 @@ bool handleControlledUnit(PetalNode *node, const TQString& name, Uml::IDType id,
* Given a PetalNode for which the mapping to Umbrello is not yet
* implemented umbrellify() is a no-op but also returns true.
*/
-bool umbrellify(PetalNode *node, UMLPackage *tqparentPkg = NULL) {
+bool umbrellify(PetalNode *node, UMLPackage *parentPkg = NULL) {
if (node == NULL) {
kError() << "umbrellify: node is NULL" << endl;
return false;
@@ -346,7 +346,7 @@ bool umbrellify(PetalNode *node, UMLPackage *tqparentPkg = NULL) {
Uml::IDType id = quid(node);
if (objType == "Class_Category") {
- UMLObject *o = Import_Utils::createUMLObject(Uml::ot_Package, name, tqparentPkg);
+ UMLObject *o = Import_Utils::createUMLObject(Uml::ot_Package, name, parentPkg);
o->setID(id);
PetalNode *logical_models = node->findAttribute("logical_models").node;
if (logical_models) {
@@ -355,13 +355,13 @@ bool umbrellify(PetalNode *node, UMLPackage *tqparentPkg = NULL) {
for (uint i = 0; i < atts.count(); i++) {
umbrellify(atts[i].second.node, localParent);
}
- } else if (!handleControlledUnit(node, name, id, tqparentPkg)) {
+ } else if (!handleControlledUnit(node, name, id, parentPkg)) {
kDebug() << "umbrellify: handling of " << objType << " " << name
<< " is not yet implemented" << endl;
}
} else if (objType == "Class") {
- UMLObject *o = Import_Utils::createUMLObject(Uml::ot_Class, name, tqparentPkg);
+ UMLObject *o = Import_Utils::createUMLObject(Uml::ot_Class, name, parentPkg);
o->setID(id);
UMLClassifier *c = static_cast<UMLClassifier*>(o);
// set stereotype
@@ -310,10 +310,10 @@ protected:
* @param name Name of the current node
* @param id TQUID of the current node
- * @param tqparentPkg Pointer to the current tqparent UMLPackage.
+ * @param parentPkg Pointer to the current tqparent UMLPackage.
* @return True if the node actually contained a controlled unit.
*/